import 'package:consoledoctor_barcode_scanner/consoledoctor_barcode_scanner.dart';
import 'package:consoledoctor_common/consoledoctor_common.dart';

class DummyOrderLookupBarcodeHandler extends SingleBarcodeLookupHandler {
  @override
  Future<ScanResult> lookupBarcode(BarcodeCapture barcodes) async {
    var barcode = barcodes.barcodes.firstWhere((b) => !b.rawValue.isNullOrEmpty());
    try {
      updateStatusMessage('Lookup up barcode...');
      await Future.delayed(Duration(seconds: 2));

      if (barcode.rawValue == '%0NE61LL15506904206901822826') {
        updateStatusMessage('Attempting to new claim DG153124...');
        await Future.delayed(Duration(seconds: 3));
        return ScanResult(outcome: ScanOutcomeType.error,
            barcode: barcode,
            barcodeFormat: barcode.format,
            heading: 'Cancelled',
            subHeading: 'DG153124',
            svgIcon: 'assets/svg/logos/swapitbox.svg',
            svgPackage: 'consoledoctor_common',
            message: 'SONY PS5\n\nFailed to acquire a new claim\nThis should be processed manually');
      }

      if (barcode.rawValue == '%0NE61LL15506904206902822826') {
        return ScanResult(outcome: ScanOutcomeType.valid,
            barcode: barcode,
            barcodeFormat: barcode.format,
            heading: 'Conf Sent',
            subHeading: 'DG121097',
            message: 'MICROSOFT Xbox Series X');
      }

      return ScanResult(outcome: ScanOutcomeType.warning,
          barcode: barcode,
          barcodeFormat: barcode.format,
          heading: 'Unknown',
          subHeading: '',
          svgIcon: barcode.rawValue.isDPDTrackingOrBarcode() ? 'packages/consoledoctor_common/assets/svg/logos/dpd-logo-mono.svg' : null,
          //svgPackage: barcode.rawValue.isDPDTrackingOrBarcode() ? 'consoledoctor_common' : null,
          message: 'This is an invalid or unknown barcode');

    }
    catch (exception) {
      return ScanResult(outcome: ScanOutcomeType.error,
          barcode: barcode,
          barcodeFormat: barcode.format,
          heading: 'Error',
          message: 'Failed lookup barcode');
    }
  }

}