import 'dart:math';

import 'package:consoledoctor_barcode_scanner/consoledoctor_barcode_scanner.dart';
import 'package:flutter/material.dart';

class CameraPinchZoomDetector extends StatefulWidget {
  const CameraPinchZoomDetector({Key? key, required this.controller}) : super(key: key);

  final BarcodeScannerController controller;

  @override
  _CameraPinchZoomDetectorState createState() =>
      _CameraPinchZoomDetectorState();
}

class _CameraPinchZoomDetectorState extends State<CameraPinchZoomDetector> {
  double _baseScale = 1.0;
  double _currentScale = 1.0;
  final double _minScale = 0.0;

  @override
  Widget build(BuildContext context) {
    return ValueListenableBuilder(
        valueListenable: widget.controller,
        builder: (context, state, child)
    {
      if (!state.isInitialized || !state.isRunning || state.maxZoomLevel == _minScale) {
        return const SizedBox.shrink();
      }

      return GestureDetector(
        onScaleStart: _handleScaleStart,
        onScaleEnd: _handleScaleEnd,
        onScaleUpdate: _handleScaleUpdate,
      );
    });
  }

  void _handleScaleStart(ScaleStartDetails details) {
    setState(() {
      _baseScale = _currentScale;
    });
  }

  void _handleScaleEnd(ScaleEndDetails details) {
    setState(() {
      _baseScale = _currentScale;
    });
  }

  void _handleScaleUpdate(ScaleUpdateDetails details) async {

    var maxZoom = widget.controller.value.maxZoomLevel;
    // Calculate logarithmic scale factor
    var logScaleFactor = (_baseScale + (maxZoom /2) * log(details.scale))
        .clamp(_minScale, maxZoom);

    double currentScale = logScaleFactor.clamp(_minScale, maxZoom);

    if (mounted) {
      setState(() {
        // Update the _currentScale
        _currentScale = currentScale;
      });
    } else {
      _currentScale = currentScale;
    }

    // Normalize to a 0 to 1 range
    double normalizedScale = (_currentScale - _minScale) / (maxZoom - _minScale);

    //print('CurrentScale: $currentScale  -  Normalized: $normalizedScale');
    // Pass normalized scale to the native side
    await widget.controller.setZoomScale(normalizedScale);
  }
}
