import 'package:consoledoctor_barcode_scanner/consoledoctor_barcode_scanner.dart';
import 'package:flutter/material.dart';

class ExposureSlider extends StatelessWidget {
  const ExposureSlider({required this.controller, super.key});

  final BarcodeScannerController controller;

  @override
  Widget build(BuildContext context) {
    return ValueListenableBuilder(
      valueListenable: controller,
      builder: (context, state, child) {
        if (!state.isInitialized || !state.isRunning) {
          return const SizedBox.shrink();
        }

        return ConstrainedBox(
          constraints: BoxConstraints(
              maxHeight: 44
          ),
          child: Padding(
            padding: const EdgeInsets.symmetric(vertical: 0, horizontal: 64),
            child: Row(
                mainAxisAlignment: MainAxisAlignment.start,
                children: [
                  Expanded(
                    child: SizedBox(
                      height: 30,
                      child: Slider(
                        value: state.exposureLevel,
                        min: state.minExposureLevel,
                        max: state.maxExposureLevel,
                        activeColor: Colors.white,
                        inactiveColor: Colors.white30,
                        onChanged: (exposure) async {
                          await controller.setExposureLevel(exposure);
                        },
                      ),
                    ),
                  ),
                  SizedBox(
                    width: 55,
                    child: Padding(
                      padding: const EdgeInsets.fromLTRB(0, 8, 8, 8),
                      child: Center(
                        child: Text('${state.exposureLevel.toStringAsFixed(1)}x', style: TextStyle(color: Colors.white),
                        ),
                      ),
                    ),
                  ),
                ]),
          ),
        );
      }
    );
  }
}